@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate musical cadence chords
 
-our $VERSION = '0.1202';
+our $VERSION = '0.1203';
 
 use Moo;
 use Music::Chord::Note;
@@ -61,21 +61,13 @@ sub cadence {
 
     die 'unknown leader' if $leading < 1 or $leading > 7;
 
-    my @scale = get_scale_notes( $key, $scale );
-
-    my $mcn = Music::Chord::Note->new;
-
-    my $mtr = Music::ToRoman->new(
-        scale_note => $key,
-        scale_name => $scale,
-        chords     => 0,
-    );
+    my @scale_notes = get_scale_notes( $key, $scale );
 
     if ( $type eq 'perfect' ) {
-        my $chord = $self->_generate_chord( $scale, $scale[4], $octave, $mtr, $mcn );
+        my $chord = $self->_generate_chord( $key, $scale, $scale_notes[4], $octave );
         push @$cadence, $chord;
 
-        $chord = $self->_generate_chord( $scale, $scale[0], $octave, $mtr, $mcn );
+        $chord = $self->_generate_chord( $key, $scale, $scale_notes[0], $octave );
         my $top = $chord->[0];
         if ( $self->format eq 'midinum' ) {
             $top += 12;
@@ -91,57 +83,57 @@ sub cadence {
         push @$cadence, $chord;
     }
     elsif ( $type eq 'imperfect' && $inversion ) {
-        my $chord = $self->_generate_chord( $scale, $scale[4], $octave, $mtr, $mcn );
+        my $chord = $self->_generate_chord( $key, $scale, $scale_notes[4], $octave );
         $chord = $self->_invert_chord( $chord, $inversion->{1}, $octave )
             if $inversion->{1};
         push @$cadence, $chord;
 
-        $chord = $self->_generate_chord( $scale, $scale[0], $octave, $mtr, $mcn );
+        $chord = $self->_generate_chord( $key, $scale, $scale_notes[0], $octave );
         $chord = $self->_invert_chord( $chord, $inversion->{2}, $octave )
             if $inversion->{2};
         push @$cadence, $chord;
     }
     elsif ( $type eq 'imperfect' ) {
-        my $note = $variation == 1 ? $scale[4] : $scale[6];
-        my $chord = $self->_generate_chord( $scale, $note, $octave, $mtr, $mcn );
+        my $note = $variation == 1 ? $scale_notes[4] : $scale_notes[6];
+        my $chord = $self->_generate_chord( $key, $scale, $note, $octave );
         push @$cadence, $chord;
 
-        $chord = $self->_generate_chord( $scale, $scale[0], $octave, $mtr, $mcn );
+        $chord = $self->_generate_chord( $key, $scale, $scale_notes[0], $octave );
         push @$cadence, $chord;
     }
     elsif ( $type eq 'evaded' && $self->seven ) {
-        my $chord = $self->_generate_chord( $scale, $scale[4], $octave, $mtr, $mcn );
+        my $chord = $self->_generate_chord( $key, $scale, $scale_notes[4], $octave );
         $chord = $self->_invert_chord( $chord, 3, $octave );
         push @$cadence, $chord;
 
-        $chord = $self->_generate_chord( $scale, $scale[0], $octave, $mtr, $mcn );
+        $chord = $self->_generate_chord( $key, $scale, $scale_notes[0], $octave );
         $chord = $self->_invert_chord( $chord, 1, $octave );
         push @$cadence, $chord;
     }
     elsif ( $type eq 'plagal' ) {
-        my $chord = $self->_generate_chord( $scale, $scale[3], $octave, $mtr, $mcn );
+        my $chord = $self->_generate_chord( $key, $scale, $scale_notes[3], $octave );
         push @$cadence, $chord;
 
-        $chord = $self->_generate_chord( $scale, $scale[0], $octave, $mtr, $mcn );
+        $chord = $self->_generate_chord( $key, $scale, $scale_notes[0], $octave );
         push @$cadence, $chord;
     }
     elsif ( $type eq 'half' ) {
-        my $chord = $self->_generate_chord( $scale, $scale[ $leading - 1 ], $octave, $mtr, $mcn );
+        my $chord = $self->_generate_chord( $key, $scale, $scale_notes[ $leading - 1 ], $octave );
         $chord = $self->_invert_chord( $chord, $inversion->{1}, $octave )
             if $inversion && $inversion->{1};
         push @$cadence, $chord;
 
-        $chord = $self->_generate_chord( $scale, $scale[4], $octave, $mtr, $mcn );
+        $chord = $self->_generate_chord( $key, $scale, $scale_notes[4], $octave );
         $chord = $self->_invert_chord( $chord, $inversion->{2}, $octave )
             if $inversion && $inversion->{2};
         push @$cadence, $chord;
     }
     elsif ( $type eq 'deceptive' ) {
-        my $chord = $self->_generate_chord( $scale, $scale[4], $octave, $mtr, $mcn );
+        my $chord = $self->_generate_chord( $key, $scale, $scale_notes[4], $octave );
         push @$cadence, $chord;
 
-        my $note = $variation == 1 ? $scale[5] : $scale[3];
-        $chord = $self->_generate_chord( $scale, $note, $octave, $mtr, $mcn );
+        my $note = $variation == 1 ? $scale_notes[5] : $scale_notes[3];
+        $chord = $self->_generate_chord( $key, $scale, $note, $octave );
         push @$cadence, $chord;
     }
     else {
@@ -186,7 +178,7 @@ sub _invert_chord {
 }
 
 sub _generate_chord {
-    my ( $self, $scale, $note, $octave, $mtr, $mcn ) = @_;
+    my ( $self, $key, $scale, $note, $octave ) = @_;
 
     # Know what chords should be diminished
     my %diminished = (
@@ -203,6 +195,12 @@ sub _generate_chord {
 
     die 'unknown scale' unless exists $diminished{$scale};
 
+    my $mtr = Music::ToRoman->new(
+        scale_note => $key,
+        scale_name => $scale,
+        chords     => 0,
+    );
+
     # Figure out if the chord is diminished, minor, or major
     my $roman = $mtr->parse($note);
     my $type  = $roman =~ /^$diminished{$scale}$/ ? 'dim' : $roman =~ /^[a-z]/ ? 'm' : '';
@@ -210,7 +208,8 @@ sub _generate_chord {
     $type .= 7
         if $self->seven;
 
-    # Generate the chord notes
+    my $mcn = Music::Chord::Note->new;
+
     my @notes = $mcn->chord( $note . $type );
 
     if ( $self->format eq 'midi' ) {
@@ -226,7 +225,6 @@ sub _generate_chord {
         die 'unknown format';
     }
 
-    # Append the octave if requested
     @notes = map { $_ . $octave } @notes
         if $octave && $self->format ne 'midinum';
 
@@ -247,7 +245,7 @@ Music::Cadence - Generate musical cadence chords
 
 =head1 VERSION
 
-version 0.1202
+version 0.1203
 
 =head1 SYNOPSIS
 
@@ -288,7 +286,6 @@ version 0.1202
   # [['Gs5','C5','Ds5'], ['Cs5','F5','Gs5','Cs6']]
 
   $mc = Music::Cadence->new(
-    key    => 'C',
     octave => 4,
     format => 'midinum',
   );
@@ -377,7 +374,8 @@ If C<midinum>, convert notes to their numerical MIDI equivalents.
 
 =head2 seven
 
-Use seventh chords (of 4 notes).  Default: C<0>
+If set, use seventh chords of four notes instead of diatonic triads.
+Default: C<0>
 
 =head1 METHODS
 
